<?php

namespace Drupal\graphql_compose_webform\Plugin\GraphQLCompose\EntityType;

use Drupal\graphql_compose\Plugin\GraphQLCompose\GraphQLComposeEntityTypeBase;
use GraphQL\Type\Definition\ObjectType;
use GraphQL\Type\Definition\Type;

/**
 * {@inheritdoc}
 *
 * @GraphQLComposeEntityType(
 *   id = "webform",
 *   prefix = "Webform",
 *   base_fields = {
 *     "langcode" = {},
 *     "created" = {},
 *     "changed" = {},
 *     "id" = {},
 *     "uuid" = {},
 *   },
 * )
 */
class Webform extends GraphQLComposeEntityTypeBase {

  /**
   * Force add a mutation for webform submission.
   */
  public function registerTypes(): void {
    parent::registerTypes();

    $this->addWebformMutation();
  }

  /**
   * Add a mutation type for the webform submit.
   */
  private function addWebformMutation() {

    $mutation_type = new ObjectType([
      'name' => 'Mutation',
      'fields' => fn() => [
        'submitWebform' => [
          'type' => $this->gqlSchemaTypeManager->get('WebformSubmission'),
          'description' => (string) $this->t('Add a webform submission.'),
          'args' => [
            'id' => [
              'type' => Type::nonNull(Type::string()),
              'description' => (string) $this->t('The webform ID.'),
            ],
            'data' => [
              'type' => Type::listOf($this->gqlSchemaTypeManager->get('KeyValueInput')),
              'description' => (string) $this->t('Webform submission data.'),
            ],
          ],
        ],
      ],
    ]);

    $this->gqlSchemaTypeManager->extend($mutation_type);
  }

}
