<?php

declare(strict_types=1);

namespace Drupal\graphql_compose_webform\Plugin\GraphQLCompose\SchemaType;

use Drupal\graphql_compose\Plugin\GraphQLCompose\GraphQLComposeSchemaTypeBase;
use GraphQL\Type\Definition\ObjectType;
use GraphQL\Type\Definition\Type;

/**
 * {@inheritDoc}
 *
 * @GraphQLComposeSchemaType(
 *   id = "Webform"
 * )
 */
class Webform extends GraphQLComposeSchemaTypeBase {

  /**
   * {@inheritDoc}
   */
  public function getTypes(): array {
    $types = [];

    // Add the "Webform" type.
    $types[] = new ObjectType([
      'name' => $this->getPluginId(),
      'description' => (string) $this->t('A webform.'),
      'fields' => fn() => [
        'id' => Type::string(),
        'label' => Type::string(),
        'description' => Type::string(),
        'elements' => Type::listOf(static::type('WebformElement')),
      ],
    ]);

    return $types;
  }

  /**
   * {@inheritDoc}
   */
  public function getExtensions(): array {
    $extensions = parent::getExtensions();

    // Add a "Webform" query to the existing "Query" type by extending it.
    $extensions[] = new ObjectType([
      'name' => 'Query',
      'fields' => fn() => [
        'webform' => [
          'type' => static::type('Webform'),
          'description' => (string) $this->t('Load a webform.'),
          'args' => [
            'id' => [
              'type' => Type::nonNull(Type::id()),
              'description' => (string) $this->t('Webform ID.'),
            ],
          ],
        ],
      ],
    ]);

    return $extensions;
  }

}
